@@ -839,6 +839,44 @@ class AsyncClient(BaseClient):
         data = package_data(remove_key(locals()))
         return await self._request_future_private_api("post", "contract_openorders", data=data)
 
+    async def future_contract_hisorders(self, symbol, trade_type, type, status, create_date, page_index=1, page_size=20,
+                                        contract_code=None, order_type=None, sort_by="create_date"):
+        """
+        获取合约历史委托
+        symbol	true	string	品种代码		支持大小写,"BTC","ETH"...
+        trade_type	true	int	交易类型		0:全部,1:买入开多,2: 卖出开空,3: 买入平空,4: 卖出平多,5: 卖出强平,6: 买入强平,7:交割平多,8: 交割平空, 11:减仓平多，12:减仓平空
+        type	true	int	类型		1:所有订单,2:结束状态的订单
+        status	true	string	订单状态		可查询多个状态，"3,4,5" , 0:全部,3:未成交, 4: 部分成交,5: 部分成交已撤单,6: 全部成交,7:已撤单
+        create_date	true	int	日期		可随意输入正整数, ，如果参数超过90则默认查询90天的数据
+        page_index	false	int	页码，不填默认第1页	1
+        page_size	false	int	每页条数，不填默认20,不得多于50	20	[1-50]
+        contract_code	false	string	合约代码
+        order_type	false	string	订单类型		1：限价单、3：对手价、4：闪电平仓、5：计划委托、6：post_only、7：最优5档、8：最优10档、9：最优20档、10：fok、11：ioc
+        sort_by	false	string	排序字段（降序），不填默认按照create_date降序	create_date	"create_date"：按订单创建时间进行降序，"update_time"：按订单更新时间进行降序
+        """
+        data = package_data(remove_key(locals()))
+        return await self._request_future_private_api("post", "contract_hisorders", data=data)
+
+    async def future_contract_hisorders_exact(self, symbol, trade_type, type, status, contract_code=None,
+                                              order_price_type=None, start_time=None, end_time=None, from_id=None,
+                                              size=20, direct="prev"):
+        """
+        组合查询合约历史委托
+        symbol 	true 	string	品种代码 	"BTC","ETH"...
+        trade_type	true	int	交易类型	0:全部,1:买入开多,2: 卖出开空,3: 买入平空,4: 卖出平多,5: 卖出强平,6: 买入强平,7:交割平多,8: 交割平空, 11:减仓平多，12:减仓平空
+        type	true	int	类型	1:所有订单,2:结束状态的订单
+        status	true	string	订单状态	可查询多个状态，"3,4,5" , 0:全部,3:未成交, 4: 部分成交,5: 部分成交已撤单,6: 全部成交,7:已撤单
+        contract_code	false	string	合约代码
+        order_price_type	false	string	订单报价类型	订单报价类型 "limit":限价，"opponent":对手价 ，"post_only":只做maker单,post only下单只受用户持仓数量限制,"optimal_5"：最优5档，"optimal_10"：最优10档，"optimal_20"：最优20档，"ioc":IOC订单，"fok"：FOK订单, "opponent_ioc"： 对手价-IOC下单，"optimal_5_ioc"：最优5档-IOC下单，"optimal_10_ioc"：最优10档-IOC下单，"optimal_20_ioc"：最优20档-IOC下单,"opponent_fok"： 对手价-FOK下单，"optimal_5_fok"：最优5档-FOK下单，"optimal_10_fok"：最优10档-FOK下单，"optimal_20_fok"：最优20档-FOK下单
+        start_time	false	long	起始时间（时间戳，单位毫秒）	详见备注
+        end_time	false	long	结束时间（时间戳，单位毫秒）	详见备注
+        from_id	false	long	查询起始id（取返回数据的query_id字段）
+        size	false	int	数据条数，默认取20，最大50	[1-50]
+        direct	false	string	查询方向	prev 向前；next 向后；默认值取prev
+        """
+        data = package_data(remove_key(locals()))
+        return await self._request_future_private_api("post", "contract_hisorders_exact", data=data)
+
     async def future_match_result(self, symbol, trade_type, create_date, contract_code=None, page_index=1, page_size=20):
         """
         获取历史成交记录
