@@ -247,7 +247,7 @@ class ReconnectingWebSocket:
             except:
                 data = uncompress_data
         elif msg.type in (aiohttp.WSMsgType.CLOSE, aiohttp.WSMsgType.CLOSED, aiohttp.WSMsgType.ERROR):
-            logging.error(f"receive invalid msg: {msg}")
+            logging.error(f"receive unexpected msg: {msg}")
             return None
         else:
             raise HuoBiWebSocketError(f"invalid msg type: {msg.type}")
